from oscar.apps.catalogue.reviews.abstract_models import \
    AbstractProductReview, AbstractVote


class ProductReview(AbstractProductReview):
    pass


class Vote(AbstractVote):
    pass
